@@ -5,9 +5,9 @@
 #       extension: .py
 #       format_name: percent
 #       format_version: '1.3'
-#       jupytext_version: 1.4.2
+#       jupytext_version: 1.11.4
 #   kernelspec:
-#     display_name: Python 3 (ipykernel)
+#     display_name: Python 3
 #     language: python
 #     name: python3
 # ---
@@ -19,8 +19,8 @@
 #
 # .. _ug_2dplots:
 #
-# Plotting 2D data
-# ================
+# 2D plotting
+# ===========
 #
 # ProPlot adds :ref:`several new features <why_plotting>` to matplotlib's
 # plotting commands using the intermediate `~proplot.axes.PlotAxes` subclass.
@@ -36,7 +36,7 @@
 # Standardized arguments
 # ----------------------
 #
-# Input arguments passed to 2D plotting commands are now uniformly
+# Input arguments passed to 2D plot commands are now uniformly
 # standardized. For each command, you can optionally omit the *x* and
 # *y* coordinates, in which case they are inferred from the data
 # (see :ref:`xarray and pandas integration <ug_2dintegration>`). If coordinates
@@ -118,13 +118,13 @@ for i, ax in enumerate(axs):
     ax.format(
         xlim=(None if i == 0 else xlim),
         ylim=(None if i == 0 else ylim),
-        title=('Auto axis limits' if i == 0 else title),
+        title=('Default axis limits' if i == 0 else title),
     )
     ax.pcolor(x, y, data, cmap=cmap, inbounds=inbounds)
 fig.format(
     xlabel='xlabel',
     ylabel='ylabel',
-    suptitle='Auto cmap normalization with in-bounds data'
+    suptitle='Default vmin/vmax restricted to in-bounds data'
 )
 
 # %% [raw] raw_mimetype="text/restructuredtext"
@@ -150,9 +150,9 @@ fig.format(
 #
 # These features restore some of the convenience you get with the builtin
 # `pandas`_ and `xarray`_ plotting functions. They are also *optional* --
-# installation of pandas and xarray are not required. All of these features
-# can be disabled by setting :rcraw:`autoformat` to ``False`` or by passing
-# ``autoformat=False`` to any plotting command.
+# installation of pandas and xarray are not required to use ProPlot. All of these
+# features can be disabled by setting :rcraw:`autoformat` to ``False`` or by
+# passing ``autoformat=False`` to any plotting command.
 
 # %%
 import xarray as xr
@@ -219,7 +219,7 @@ ax.format(xtickminor=False, yreverse=True, yformatter='%b', ytickminor=False)
 # It is often useful to create `~proplot.colors.ContinuousColormap`\ s
 # on-the-fly, without explicitly calling the `~proplot.constructor.Colormap`
 # :ref:`constructor function <why_constructor>`. You can do so using the `cmap`
-# and `cmap_kw` keywords, available with most `~proplot.axes.PlotAxes` 2d plotting
+# and `cmap_kw` keywords, available with most `~proplot.axes.PlotAxes` 2D plot
 # commands. For example, to create and apply a monochromatic colormap, you can use
 # ``cmap='color_name'`` (see the :ref:`colormaps section <ug_cmaps>` for more info).
 # You can also create on-the-fly "qualitative" `~proplot.colors.DiscreteColormap`\ s
@@ -231,9 +231,9 @@ ax.format(xtickminor=False, yreverse=True, yformatter='%b', ytickminor=False)
 # A normalizer can be selected from its "registered" name using the
 # `~proplot.constructor.Norm` :ref:`constructor function <why_constructor>`. You
 # can also build a normalizer on-the-fly using the `norm` and `norm_kw` keywords,
-# again available with most `~proplot.axes.PlotAxes` 2d plotting commands.
-# If you want to work with normalizer classes directly, they are also imported
-# into the top-level namespace (e.g., ``pplt.LogNorm(...)`` is allowed). To
+# again available with most `~proplot.axes.PlotAxes` 2D plot commands.
+# If you want to work with the normalizer classes directly, they are available in
+# the top-level namespace (e.g., ``norm=pplt.LogNorm(...)`` is allowed). To
 # explicitly set the normalization range, you can pass the usual `vmin` and `vmax`
 # keywords to the plotting command. See the :ref:`next section <ug_discrete>` for
 # more details on colormap normalization.
@@ -293,29 +293,25 @@ pplt.rc.reset()
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_discrete:
 #
-# Distinct colormap levels
-# ------------------------
+# Distinct levels
+# ---------------
 #
-# In ProPlot, when colormaps are applied to plots, the color levels are
-# "discretized" using `~proplot.colors.DiscreteNorm`. This converts
-# data values into colors by first (1) transforming
-# the data using an arbitrary *continuous* normalizer (e.g.,
-# `~matplotlib.colors.Normalize` or `~matplotlib.colors.LogNorm`), then
-# (2) mapping the normalized data to *distinct* color levels. This is
-# similar to matplotlib's `~matplotlib.colors.BoundaryNorm`, but more
-# flexible. Distinct levels can help readers discern exact
-# numeric values and tend to reveal qualitative structure in the data.
-# They are especially useful for `~proplot.axes.PlotAxes.pcolor` and
-# `~proplot.axes.PlotAxes.pcolormesh` plots, analogous to
-# `~proplot.axes.PlotAxes.contourf`. By default, distinct levels are disabled for
-# `~proplot.axes.PlotAxes.imshow`, `~proplot.axes.PlotAxes.matshow`,
-# `~proplot.axes.PlotAxes.spy`, `~proplot.axes.PlotAxes.hexbin`,
-# `~proplot.axes.PlotAxes.hist2d`, and `~proplot.axes.PlotAxes.scatter` plots.
-# To explicitly toggle it, pass ``discrete=False`` or ``discrete=True`` to any
-# plotting command that accepts a `cmap` argument, or change :rcraw:`image.discrete`.
+# By default, ProPlot "discretizes" the possible colormap colors for contour plotting
+# commands like `~proplot.axes.PlotAxes.contour` and `~proplot.axes.PlotAxes.contourf`
+# and pseudocolor plotting commands like `~proplot.axes.PlotAxes.pcolor` and
+# `~proplot.axes.PlotAxes.pcolormesh` using `~proplot.colors.DiscreteNorm`, analogous
+# to matplotlib's `~matplotlib.colors.BoundaryNorm`. `~proplot.colors.DiscreteNorm`
+# converts data values into colors by (1) transforming the data using an
+# arbitrary continuous normalizer (e.g., `~matplotlib.colors.Normalize`,
+# `~matplotlib.colors.LogNorm`, `~proplot.colors.SegmentedNorm`, or
+# `~proplot.colors.DivergingNorm`), then (2) mapping the normalized data to distinct
+# color levels. Distinct levels can help readers discern exact numeric values and tend
+# to reveal qualitative structure in the data. To explicitly toggle distinct levels
+# on or off, pass ``discrete=False`` or ``discrete=True`` to any plotting command that
+# accepts a `cmap` argument, or change :rcraw:`image.discrete`.
 #
 # `~proplot.colors.DiscreteNorm` also repairs the colormap end-colors by
-# ensuring the following conditions are met (this may seem nitpicky, but
+# ensuring the following conditions are met (this may seem excessive, but
 # it is crucial for plots with very few levels):
 #
 # #. All colormaps always span the *entire color range*,
@@ -323,15 +319,21 @@ pplt.rc.reset()
 # #. Cyclic colormaps always have *distinct color levels*
 #    on either end of the colorbar.
 #
-# The colormap levels used with `~proplot.colors.DiscreteNorm` can be configured
-# with the `levels`, `values`, or `N` keywords. If you pass an integer,
-# approximately that many boundaries are automatically generated at "nice"
-# intervals. The keywords `vmin`, `vmax`, `locator`, and `locator_kw` control how
-# the automatic intervals are chosen. You can also use the `positive`, `negative`,
-# and `symmetric` keywords to ensure that automatically-generated levels are
-# strictly positive, strictly negative, or symmetric about zero (respectively).
-# To generate your own level lists, the `~proplot.utils.arange` and
-# `~proplot.utils.edges` commands may be useful.
+# The level edges or centers used with `~proplot.colors.DiscreteNorm` can be explicitly
+# specified using the `levels` and `values` keywords (the `~proplot.utils.arange` and
+# `~proplot.utils.edges` commands are useful for generating level lists). You can
+# also pass an integer to these keywords (or to the `N` keyword) to automatically
+# generate approximately that many level edges or centers at "nice" intervals. The
+# algorithm used to generate levels is similar to matplotlib's algorithm for selecting
+# contour levels. The default number of levels is controlled by :rcraw:`cmap.levels`,
+# and the algorithm is constrained by the keywords `vmin`, `vmax`, `locator`, and
+# `locator_kw` -- for example, ``vmin=100`` ensures the minimum level is
+# greater than or equal to ``100``, and ``locator=5`` ensures a level step size of 5
+# (see the :ref:`axis locators <ug_locators>` section for details). You can also use
+# the keywords `positive`, `negative`, and `symmetric` to ensure that your levels are
+# strictly positive, strictly negative, or symmetric about zero, or use the `nozero`
+# keyword to remove the zero level
+# (useful for single-color `~proplot.axes.PlotAxes.contour` plots).
 
 # %%
 import proplot as pplt
@@ -390,8 +392,8 @@ for i, extend in enumerate(('min', 'max', 'neither', 'both')):
 # %% [raw] raw_mimetype="text/restructuredtext" tags=[]
 # .. _ug_autonorm:
 #
-# Auto colormap normalization
-# ---------------------------
+# Auto normalization
+# ------------------
 #
 # By default, colormaps are normalized to span from roughly the minimum
 # data value to the maximum data value. However in the presence of outliers,
@@ -399,11 +401,11 @@ for i, extend in enumerate(('min', 'max', 'neither', 'both')):
 # behavior, inspired by the `xarray option
 # <http://xarray.pydata.org/en/stable/user-guide/plotting.html#robust>`__
 # of the same name. Passing ``robust=True`` to a `~proplot.axes.PlotAxes`
-# 2d plotting command will limit the default colormap normalization between
+# 2D plot command will limit the default colormap normalization between
 # the 2nd and 98th data percentiles. This range can be customized by passing
 # an integer to `robust` (e.g. ``robust=90`` limits the normalization range
 # between the 5th and 95th percentiles) or by passing a 2-tuple to `robust`
-# (e.g. ``robust=(0, 90)`` will limit the normalization range between the
+# (e.g. ``robust=(0, 90)`` limits the normalization range between the
 # data minimum and the 90th percentile). This can be turned on persistently
 # by setting :rcraw:`cmap.robust` to ``True``.
 #
@@ -453,8 +455,8 @@ pplt.rc.reset()
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_norm:
 #
-# Special colormap normalizers
-# ----------------------------
+# Special normalizers
+# -------------------
 #
 # ProPlot includes a few new colormap normalizers. `~proplot.colors.SegmentedNorm`
 # provides even color gradations with respect to *index* for an arbitrary
@@ -531,8 +533,8 @@ for data, mode, fair in zip(
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_labels:
 #
-# Contour and gridbox labels
-# --------------------------
+# Quick labels
+# ------------
 #
 # You can now quickly add labels to `~proplot.axes.PlotAxes.contour`,
 # `~proplot.axes.PlotAxes.contourf`, `~proplot.axes.PlotAxes.pcolor`,
@@ -566,24 +568,25 @@ axs.format(xlabel='xlabel', ylabel='ylabel', suptitle='Labels demo')
 # Heatmap with labeled boxes
 ax = axs[0]
 m = ax.heatmap(
-    data, cmap='rocket', labels=True,
-    precision=2, labels_kw={'weight': 'bold'}
+    data, cmap='rocket',
+    labels=True, precision=2, labels_kw={'weight': 'bold'}
 )
 ax.format(title='Heatmap with labels')
 
 # Filled contours with labels
 ax = axs[1]
 m = ax.contourf(
-    data.cumsum(axis=0), labels=True,
-    cmap='rocket', labels_kw={'weight': 'bold'}
+    data.cumsum(axis=0), cmap='rocket',
+    labels=True, labels_kw={'weight': 'bold'}
 )
 ax.format(title='Filled contours with labels')
 
-# Line contours with labels
+# Line contours with labels and no zero level
+data = 5 * (data - 0.45).cumsum(axis=0) - 2
 ax = axs[2]
 ax.contour(
-    data.cumsum(axis=1) - 2, labels=True,
-    color='gray8', labels_kw={'weight': 'bold'}
+    data, nozero=True, color='gray8',
+    labels=True, labels_kw={'weight': 'bold'}
 )
 ax.format(title='Line contours with labels')
 
