@@ -9,11 +9,13 @@
 # full list see the documentation:
 # http://www.sphinx-doc.org/en/master/config
 
+
 # -- Path setup --------------------------------------------------------------
 
-import os
-import sys
 import datetime
+import os
+import subprocess
+import sys
 
 # Add proplot to path for sphinx-automodapi
 sys.path.insert(0, os.path.abspath('..'))
@@ -23,17 +25,27 @@ sys.path.append(os.path.abspath('.'))
 
 # Hack to get basemap to work
 # See: https://github.com/readthedocs/readthedocs.org/issues/5339
-on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-if on_rtd:
-    os.environ['PROJ_LIB'] = (
-        '{}/{}/share/proj'.format(
-            os.environ['CONDA_ENVS_PATH'], os.environ['CONDA_DEFAULT_ENV']
-        )
+if os.environ.get('READTHEDOCS', None) == 'True':
+    os.environ['GEOS_DIR'] = os.path.join(
+        os.environ['CONDA_ENVS_PATH'], os.environ['CONDA_DEFAULT_ENV']
+    )
+    os.environ['PROJ_LIB'] = os.path.join(
+        os.environ['CONDA_ENVS_PATH'], os.environ['CONDA_DEFAULT_ENV'], 'share', 'proj'
     )
 else:
-    os.environ['PROJ_LIB'] = '{}/share/proj'.format(
-        os.environ['CONDA_PREFIX']
-    )
+    os.environ['GEOS_DIR'] = os.environ['CONDA_PREFIX']
+    os.environ['PROJ_LIB'] = os.path.join(os.environ['CONDA_PREFIX'], 'share', 'proj')
+
+# Install basemap if does not exist
+# Extremely ugly but impossible to install in environment.yml. Must set
+# GEOS_DIR before installing so cannot install with pip and basemap conflicts
+# with conda > 0.19 so cannot install with conda in environment.yml.
+try:
+    import mpl_toolkits.basemap  # noqa: F401
+except ImportError:
+    cmd = ['pip', 'install', 'git+https://github.com/matplotlib/basemap@v1.2.2rel']
+    subprocess.check_call(cmd)
+
 
 # -- Project information -----------------------------------------------------
 
@@ -48,6 +60,7 @@ version = ''
 # The full version, including alpha/beta/rc tags
 release = ''
 
+
 # -- General configuration ---------------------------------------------------
 
 # If your documentation needs a minimal Sphinx version, state it here.
@@ -246,6 +259,7 @@ rc._save_yaml(os.path.join('_static', 'proplotrc'))
 # :func:`name`, :module:`name`, etc.
 default_role = 'py:obj'
 
+
 # -- Options for HTML output -------------------------------------------------
 
 # Add any paths that contain custom static files (such as style sheets) here,
@@ -282,6 +296,7 @@ html_theme_options = {
     'prev_next_buttons_location': 'bottom',  # top and bottom
 }
 
+
 # -- Options for HTMLHelp output ---------------------------------------------
 
 # Output file base name for HTML help builder.
@@ -347,8 +362,6 @@ texinfo_documents = [
 ]
 
 
-# -- Extension configuration -------------------------------------------------
-
 # -- Options for todo extension ----------------------------------------------
 
 # If true, `todo` and `todoList` produce output, else they produce nothing.
