@@ -56,7 +56,16 @@ __all__ = [
 ]
 
 # Constants
-REGEX_STRING = re.compile('\\A(\'.*\'|".*")\\Z')
+COLORS_KEEP = (
+    'red',
+    'green',
+    'blue',
+    'cyan',
+    'yellow',
+    'magenta',
+    'white',
+    'black'
+)
 FONT_KEYS = (  # re-apply these whenever 'font.size' is changed
     'abc.size',
     'axes.labelsize',
@@ -376,18 +385,15 @@ def _parse_format(rc_kw=None, rc_mode=None, **kwargs):
     """
     # NOTE: rc_mode == 2 applies only the updated params. A power user
     # could use ax.format(rc_mode=0) to re-apply all the current settings
-    kw = {}
-    rc_kw = rc_kw or {}
-    rc_mode = _not_none(rc_mode, 2)  # 2 applies only the updated params
-    for key, value in kwargs.items():
-        rc_key = rcsetup._rc_nodots.get(key, None)
-        if rc_key in ('alpha', 'facecolor', 'edgecolor', 'linewidth'):
-            rc_key = None  # former renamed settings
-        if rc_key is None:
-            kw[key] = value
-        else:
-            rc_kw[rc_key] = value
-    return rc_kw, rc_mode, kw
+    kw = rc_kw or {}
+    mode = _not_none(rc_mode, 2)  # only apply updated params by default
+    for key, value in tuple(kwargs.items()):
+        name = rcsetup._rc_nodots.get(key, None)
+        if name in ('alpha', 'facecolor', 'edgecolor', 'linewidth'):
+            name = None  # former renamed settings
+        if name is not None:
+            kw[name] = kwargs.pop(key)
+    return kw, mode, kwargs
 
 
 def _translate_loc(loc, mode, *, default=None, **kwargs):
@@ -658,8 +664,8 @@ def register_colors(*args, user=None, default=False, space=None, margin=None, **
         The margin by which the normalized hue, saturation, and luminance of each
         XKCD color must differ from the channel values of the other XKCD colors to
         be deemed "perceptually distinct" and registered. Must fall between ``0``
-        and ``1`` (``0`` will register all colors). Default is ``0.1``. If
-        passed then `default` is set to ``True``.
+        and ``1`` (``0`` will register all colors). Default is ``0.1``. If passed
+        then `default` is set to ``True``.
     **kwargs
         Additional color name specifications passed as keyword arguments rather
         than positional dictionaries.
@@ -671,15 +677,20 @@ def register_colors(*args, user=None, default=False, space=None, margin=None, **
     register_fonts
     proplot.demos.show_colors
     """
-    # Add in base colors and CSS4 colors so user has no surprises
     from . import colors as pcolors
     default = default or space is not None or margin is not None
     margin = _not_none(margin, 0.1)
     space = _not_none(space, 'hcl')
-    if default:
-        pcolors._color_database.clear()  # MutableMapping ensures cache also clears
-        for src in (mcolors.CSS4_COLORS, pcolors.COLORS_BASE):
-            pcolors._color_database.update(src)
+
+    # Remove previously registered colors
+    # NOTE: Try not to touch matplotlib colors for compatibility
+    srcs = {'xkcd': pcolors.COLORS_XKCD, 'opencolor': pcolors.COLORS_OPEN}
+    if default:  # possibly slow but not these dicts are empty on startup
+        for src in srcs.values():
+            for key in src:
+                if key not in COLORS_KEEP:
+                    pcolors._color_database.pop(key, None)  # this also clears cache
+            src.clear()
 
     # Register input colors
     user = _not_none(user, not bool(args) and not bool(kwargs))  # skip if args passed
@@ -697,7 +708,6 @@ def register_colors(*args, user=None, default=False, space=None, margin=None, **
 
     # Load colors from file and get their HCL values
     # NOTE: Colors that come *later* overwrite colors that come earlier.
-    srcs = {'opencolor': pcolors.COLORS_OPEN, 'xkcd': pcolors.COLORS_XKCD}
     for i, path in _iter_data_objects('colors', *paths, user=user, default=default):
         loaded = pcolors._load_colors(path, warn_on_failure=True)
         if i == 0:
@@ -706,8 +716,10 @@ def register_colors(*args, user=None, default=False, space=None, margin=None, **
                 raise RuntimeError(f'Unknown proplot color database {path!r}.')
             src = srcs[cat]
             if cat == 'xkcd':
+                for key in COLORS_KEEP:
+                    loaded[key] = pcolors._color_database[key]  # keep the same
                 loaded = pcolors._standardize_colors(loaded, space, margin)
-            loaded = {k: c for k, c in loaded.items() if k not in pcolors.COLORS_BASE}
+            src.clear()
             src.update(loaded)  # needed for demos.show_colors()
         pcolors._color_database.update(loaded)
 
@@ -765,8 +777,8 @@ def register_fonts(*args, user=True, default=False):
     fnames_proplot -= fnames_proplot_ttc
     if not fnames_all >= fnames_proplot:
         warnings._warn_proplot(
-            'Rebuilding font cache. This may increase import time. '
-            'Usually happens after importing proplot for the first time.'
+            'Rebuilding font cache. This usually happens '
+            'after installing or updating proplot.'
         )
         if hasattr(mfonts.fontManager, 'addfont'):
             # Newer API lets us add font files manually and deprecates TTFPATH. However
