@@ -3,6 +3,7 @@
 The figure class used for all ProPlot figures.
 """
 import functools
+import inspect
 import os
 from numbers import Integral
 
@@ -518,15 +519,15 @@ class Figure(mfigure.Figure):
 
         Other parameters
         ----------------
+        %(figure.format)s
         **kwargs
             Passed to `matplotlib.figure.Figure`.
 
         See also
         --------
+        Figure.format
         proplot.ui.figure
         proplot.ui.subplots
-        proplot.figure.Figure.add_subplot
-        proplot.figure.Figure.subplots
         matplotlib.figure.Figure
         """
         # Add figure sizing settings
@@ -686,6 +687,8 @@ class Figure(mfigure.Figure):
         self._subplot_counter = 0  # avoid add_subplot() returning an existing subplot
         self._is_adjusting = False
         self._is_authorized = False
+        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
+        kw_format = _pop_params(kwargs, self._format_signature)
         with self._context_authorized():
             super().__init__(**kwargs)
 
@@ -717,7 +720,10 @@ class Figure(mfigure.Figure):
         else:
             context = {'mathtext.fallback_to_cm': bool(mathtext_fallback)}
         self._mathtext_context = context
-        self.format(rc_mode=1)  # initiate super label and title settings
+
+        # Format figure
+        # NOTE: This ignores user-input rc_mode.
+        self.format(rc_kw=rc_kw, rc_mode=1, skip_axes=True, **kw_format)
 
     def _context_adjusting(self, cache=True):
         """
@@ -814,9 +820,7 @@ class Figure(mfigure.Figure):
         else:
             pos = 0.5 * (box_lo.y1 + box_hi.y0)  # 'lo' is actually on top of figure
         ax = axs[(np.argmin(ranges[:, 0]) + np.argmax(ranges[:, 1])) // 2]
-        other = getattr(ax, f'_share{s}')
-        if other and other._panel_parent:  # deflect to shared panel axes
-            ax = other
+        ax = ax._panel_parent or ax  # always use main subplot for spanning labels
         return pos, ax
 
     def _get_offset_coord(self, side, axs, renderer, *, pad=None, extra=None):
@@ -1122,7 +1126,7 @@ class Figure(mfigure.Figure):
         if title is not None:
             self._suptitle.set_text(title)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     @docstring._snippet_manager
     def add_axes(self, rect, **kwargs):
         """
@@ -1131,7 +1135,7 @@ class Figure(mfigure.Figure):
         kwargs = self._parse_proj(**kwargs)
         return super().add_axes(rect, **kwargs)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     @docstring._snippet_manager
     def add_subplot(self, *args, number=None, **kwargs):
         """
@@ -1247,19 +1251,19 @@ class Figure(mfigure.Figure):
             # 1. 'string' or {1: 'string1', (2, 3): 'string2'}
             if not kw:
                 if np.iterable(input) and not isinstance(input, (str, dict)):
-                    value = {num + 1: item for num, item in enumerate(input)}
+                    input = {num + 1: item for num, item in enumerate(input)}
                 elif not isinstance(input, dict):
-                    value = {range(1, naxs + 1): input}
+                    input = {range(1, naxs + 1): input}
             # 2. {'prop': value} or {1: {'prop': value1}, (2, 3): {'prop': value2}}
             else:
                 nested = [isinstance(_, dict) for _ in input.values()]
                 if not any(nested):  # any([]) == False
-                    value = {range(1, naxs + 1): input.copy()}
+                    input = {range(1, naxs + 1): input.copy()}
                 elif not all(nested):
-                    raise ValueError(f'Invalid input {value!r}.')
+                    raise ValueError(f'Invalid input {input!r}.')
             # Unfurl keys that contain multiple axes numbers
             output = {}
-            for nums, item in value.items():
+            for nums, item in input.items():
                 nums = np.atleast_1d(nums)
                 for num in nums.flat:
                     output[num] = item.copy() if kw else item
@@ -1269,7 +1273,7 @@ class Figure(mfigure.Figure):
                     output[num] = {} if kw else default
             if output.keys() != set(range(1, naxs + 1)):
                 raise ValueError(
-                    f'Have {naxs} axes, but {value!r} includes props for the axes: '
+                    f'Have {naxs} axes, but {input!r} includes props for the axes: '
                     + ', '.join(map(repr, sorted(output))) + '.'
                 )
             return output
@@ -1403,6 +1407,7 @@ class Figure(mfigure.Figure):
             gs._auto_layout_space(renderer)
         _align_content()
 
+    @docstring._snippet_manager
     def format(
         self, axs=None,
         figtitle=None, suptitle=None, suptitle_kw=None,
@@ -1413,8 +1418,8 @@ class Figure(mfigure.Figure):
         rowlabels=None, collabels=None, **kwargs,  # aliases
     ):
         """
-        Format the figure labels and title and call ``format`` for
-        the input axes. By default the numbered subplots are used.
+        Modify figure-wide labels and call ``format`` for the
+        input axes. By default the numbered subplots are used.
 
         Parameters
         ----------
@@ -1447,8 +1452,8 @@ class Figure(mfigure.Figure):
         proplot.config.Configurator.context
         """
         # Initiate context block
-        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
         skip_axes = kwargs.pop('skip_axes', False)  # internal keyword arg
+        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
         with rc.context(rc_kw, mode=rc_mode):
             # Update background patch
             kw = rc.fill({'facecolor': 'figure.facecolor'}, context=True)
@@ -1501,10 +1506,10 @@ class Figure(mfigure.Figure):
         for ax in axs:
             ax.format(rc_kw=rc_kw, rc_mode=rc_mode, skip_figure=True, **kwargs)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     @docstring._snippet_manager
     def colorbar(
-        self, mappable, values=None, *, loc=None, location=None,
+        self, mappable, values=None, loc=None, location=None,
         row=None, col=None, rows=None, cols=None, span=None,
         space=None, pad=None, width=None, **kwargs
     ):
@@ -1535,8 +1540,22 @@ class Figure(mfigure.Figure):
         proplot.axes.Axes.colorbar
         matplotlib.figure.Figure.colorbar
         """
+        # Backwards compatibility
         ax = kwargs.pop('ax', None)
         cax = kwargs.pop('cax', None)
+        if isinstance(values, maxes.Axes):
+            cax = _not_none(cax_positional=values, cax=cax)
+            values = None
+        if isinstance(loc, maxes.Axes):
+            ax = _not_none(ax_positional=loc, ax=ax)
+            loc = None
+        # Helpful warning
+        if kwargs.pop('use_gridspec', None) is not None:
+            warnings._warn_proplot(
+                "Ignoring the 'use_gridspec' keyword. ProPlot always allocates "
+                'additional space for colorbars using the figure gridspec '
+                "rather than 'stealing space' from the parent subplot."
+            )
         # Fill this axes
         if cax is not None:
             with context._state_context(cax, _internal_call=True):  # do not wrap pcolor
@@ -1555,10 +1574,10 @@ class Figure(mfigure.Figure):
             )
             return ax.colorbar(mappable, values, loc='fill', **kwargs)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     @docstring._snippet_manager
     def legend(
-        self, handles=None, labels=None, *, loc=None, location=None,
+        self, handles=None, labels=None, loc=None, location=None,
         row=None, col=None, rows=None, cols=None, span=None,
         space=None, pad=None, width=None, **kwargs
     ):
@@ -1605,7 +1624,7 @@ class Figure(mfigure.Figure):
         """
         return self.savefig(filename, **kwargs)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     @docstring._snippet_manager
     def savefig(self, filename, **kwargs):
         """
@@ -1617,7 +1636,7 @@ class Figure(mfigure.Figure):
             filename = os.path.expanduser(filename)
         super().savefig(filename, **kwargs)
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     def set_canvas(self, canvas):
         """
         Set the figure canvas. Add monkey patches for the instance-level
@@ -1654,7 +1673,7 @@ class Figure(mfigure.Figure):
         else:
             return np.all(np.isclose(figsize, figsize_active, rtol=0, atol=eps))
 
-    @docstring._concatenate_original
+    @docstring._concatenate_inherited
     def set_size_inches(self, w, h=None, *, forward=True, internal=False, eps=None):
         """
         Set the figure size. If this is being called manually or from an interactive
@@ -1766,6 +1785,11 @@ class Figure(mfigure.Figure):
             [ax for num, ax in sorted(self._subplot_dict.items())]
         )
 
+    # Apply signature obfuscation after getting keys
+    # NOTE: This is needed for axes and figure instantiation.
+    _format_signature = inspect.signature(format)
+    format = docstring._obfuscate_kwargs(format)
+
 
 # Add deprecated properties. There are *lots* of properties we pass to Figure
 # and do not like idea of publicly tracking every single one of them. If we
