@@ -12,18 +12,20 @@ import numpy.ma as ma
 
 from . import ticker as pticker
 from .internals import ic  # noqa: F401
-from .internals import _not_none, _version_mpl, warnings
+from .internals import _not_none, dependencies, warnings
 
 scales = mscale._scale_mapping
 
 __all__ = [
-    'CutoffScale', 'ExpScale',
+    'CutoffScale',
+    'ExpScale',
     'FuncScale',
     'InverseScale',
     'LinearScale',
     'LogitScale',
     'LogScale',
-    'MercatorLatitudeScale', 'PowerScale',
+    'MercatorLatitudeScale',
+    'PowerScale',
     'SineLatitudeScale',
     'SymmetricalLogScale',
 ]
@@ -38,7 +40,7 @@ def _parse_logscale_args(*keys, **kwargs):
     # NOTE: Scale classes ignore unused arguments with warnings, but matplotlib 3.3
     # version changes the keyword args. Since we can't do a try except clause, only
     # way to avoid warnings with 3.3 upgrade is to test version string.
-    kwsuffix = '' if _version_mpl >= 3.3 else 'x'
+    kwsuffix = '' if dependencies._version_mpl >= 3.3 else 'x'
     for key in keys:
         # Remove duplicates
         opts = {
@@ -65,7 +67,7 @@ def _parse_logscale_args(*keys, **kwargs):
 
 class _Scale(object):
     """
-    Mixin class that standardizes the behavior of
+    Mix-in class that standardizes the behavior of
     `~matplotlib.scale.ScaleBase.set_default_locators_and_formatters`
     and `~matplotlib.scale.ScaleBase.get_transform`. Also overrides
     `__init__` so you no longer have to instantiate scales with an
@@ -185,9 +187,9 @@ class LogScale(_Scale, mscale.LogScale):
         nonpos : {'mask', 'clip'}, optional
             Non-positive values in *x* or *y* can be masked as
             invalid, or clipped to a very small positive number.
-        subs : list of int, optional
+        subs : sequence of int, optional
             Default *minor* tick locations are on these multiples of each power
-            of the base. For example, ``subs=(1,2,5)`` draws ticks on 1, 2, 5,
+            of the base. For example, ``subs=(1, 2, 5)`` draws ticks on 1, 2, 5,
             10, 20, 50, etc. The default is ``subs=numpy.arange(1, 10)``.
         basex, basey, nonposx, nonposy, subsx, subsy
             Aliases for the above keywords. These used to be conditional
@@ -327,24 +329,24 @@ class FuncScale(_Scale, mscale.ScaleBase):
             forward, inverse = inverse, forward
         functransform = FuncTransform(forward, inverse)
 
-        # Manage the "parent" axis scale
-        # NOTE: Makes sense to use the "inverse" function here because this is
+        # Manage the parent axis scale
+        # NOTE: Must transform parent scale cutoff arguments as well.
+        # NOTE: Makes sense to use the inverse function here because this is
         # a transformation from some *other* axis to this one, not vice versa.
-        if isinstance(parent_scale, mscale.ScaleBase):
+        if parent_scale is None:
+            pass
+        elif isinstance(parent_scale, mscale.ScaleBase):
             if isinstance(parent_scale, mscale.SymmetricalLogScale):
-                kwargs = {
-                    key: getattr(parent_scale, key)
-                    for key in ('base', 'linthresh', 'linscale', 'subs')
-                }
+                keys = ('base', 'linthresh', 'linscale', 'subs')
+                kwargs = {key: getattr(parent_scale, key) for key in keys}
                 kwargs['linthresh'] = inverse(kwargs['linthresh'])
                 parent_scale = SymmetricalLogScale(**kwargs)
-            elif isinstance(parent_scale, CutoffScale):
-                args = list(parent_scale.args)  # copy
-                for i in range(0, len(args), 2):
-                    args[i] = inverse(args[i])
+            if isinstance(parent_scale, CutoffScale):
+                args = list(parent_scale.args)  # mutable copy
+                args[::2] = (inverse(arg) for arg in args[::2])  # transform cutoffs
                 parent_scale = CutoffScale(*args)
             functransform = parent_scale.get_transform() + functransform
-        elif parent_scale is not None:
+        else:
             raise ValueError(
                 f'parent_scale {parent_scale!r} must be a ScaleBase instance, '
                 f'not {type(parent_scale)!r}.'
@@ -367,7 +369,10 @@ class FuncScale(_Scale, mscale.ScaleBase):
             if isinstance(scale, mscale.LinearScale):
                 continue
             for name in (
-                'major_locator', 'minor_locator', 'major_formatter', 'minor_formatter'
+                'major_locator',
+                'minor_locator',
+                'major_formatter',
+                'minor_formatter'
             ):
                 attr = f'_default_{name}'
                 obj = getattr(scale, attr)
@@ -603,7 +608,7 @@ class MercatorLatitudeScale(_Scale, mscale.ScaleBase):
             raise ValueError("Mercator scale 'thresh' must be <= 90.")
         self._thresh = thresh
         self._transform = MercatorLatitudeTransform(thresh)
-        self._default_major_formatter = pticker.AutoFormatter(suffix='\N{DEGREE SIGN}')  # noqa: E501
+        self._default_major_formatter = pticker.AutoFormatter(suffix='\N{DEGREE SIGN}')
 
     def limit_range_for_scale(self, vmin, vmax, minpos):  # noqa: U100
         """
@@ -803,12 +808,11 @@ class CutoffTransform(mtransforms.Transform):
             raise ValueError('Final scale must be finite.')
         if any(dists < 0):
             raise ValueError('Thresholds must be monotonically increasing.')
-        if any((dists == 0) | (scales == 0)) and (
-                any((dists == 0) != (scales == 0)) or zero_dists is None):
-            raise ValueError(
-                'Got zero scales and distances in different places or '
-                'zero_dists is None.'
-            )
+        if any((dists == 0) | (scales == 0)):
+            if zero_dists is None:
+                raise ValueError('Keyword zero_dists is required for discrete steps.')
+            if any((dists == 0) != (scales == 0)):
+                raise ValueError('Input scales disagree with discrete step locations.')
         self._scales = scales
         self._threshs = threshs
         with np.errstate(divide='ignore', invalid='ignore'):
@@ -827,7 +831,7 @@ class CutoffTransform(mtransforms.Transform):
 
     def transform_non_affine(self, a):
         # Cannot do list comprehension because this method sometimes
-        # received non-1d arrays
+        # received non-1D arrays
         dists = self._dists
         scales = self._scales
         threshs = self._threshs
@@ -915,7 +919,7 @@ def _scale_factory(scale, axis, *args, **kwargs):  # noqa: U100
         if scale not in scales:
             raise ValueError(
                 f'Unknown axis scale {scale!r}. Options are '
-                + ', '.join(map(repr, scales.keys())) + '.'
+                + ', '.join(map(repr, scales)) + '.'
             )
         return scales[scale](*args, **kwargs)
 
