@@ -3,13 +3,17 @@
 Various `~matplotlib.ticker.Locator` and `~matplotlib.ticker.Formatter`
 classes.
 """
-import re
-import numpy as np
-import matplotlib.ticker as mticker
 import locale
+import re
 from fractions import Fraction
+
+import matplotlib.ticker as mticker
+import numpy as np
+
+from .config import rc
 from .internals import ic  # noqa: F401
-from .internals import docstring, _dummy_context, _state_context, _not_none
+from .internals import _not_none, context, docstring
+
 try:
     import cartopy.crs as ccrs
     from cartopy.mpl.ticker import (
@@ -19,38 +23,52 @@ except ModuleNotFoundError:
     ccrs = None
     _PlateCarreeFormatter = LatitudeFormatter = LongitudeFormatter = object
 
+# NOTE: Keep IndexFormatter out of __all__ since we don't want it documented
+# on website. Just represents a matplotlib replacement. However *do* keep
+# it public so people can access it from module like all other classes.
 __all__ = [
     'AutoFormatter',
     'FracFormatter',
-    'LongitudeLocator',
-    'LatitudeLocator',
     'SciFormatter',
     'SigFigFormatter',
     'SimpleFormatter',
+    'DegreeFormatter',
+    'LongitudeFormatter',
+    'LatitudeFormatter',
+    'DegreeLocator',
+    'LongitudeLocator',
+    'LatitudeLocator',
 ]
 
 REGEX_ZERO = re.compile('\\A[-\N{MINUS SIGN}]?0(.0*)?\\Z')
 REGEX_MINUS = re.compile('\\A[-\N{MINUS SIGN}]\\Z')
 REGEX_MINUS_ZERO = re.compile('\\A[-\N{MINUS SIGN}]0(.0*)?\\Z')
 
-docstring.snippets['formatter.params'] = """
+_precision_docstring = """
+precision : int, optional
+    The maximum number of digits after the decimal point. Default is ``6``
+    when `zerotrim` is ``True`` and ``2`` otherwise.
+"""
+_zerotrim_docstring = """
 zerotrim : bool, optional
-    Whether to trim trailing zeros. Default is :rc:`formatter.zerotrim`.
-tickrange : (float, float), optional
+    Whether to trim trailing decimal zeros.
+    Default is :rc:`formatter.zerotrim`.
+"""
+_auto_docstring = """
+tickrange : 2-tuple of float, optional
     Range within which major tick marks are labelled. Default is
     ``(-np.inf, np.inf)``.
-wraprange : (float, float), optional
-    Range outside of which tick values are wrapped. For example, ``(0, 2)``
-    will format a value of ``2.5`` as ``0.5``, and ``(-180, 180)`` will
-    format a value of ``200`` as ``-180 + 20 == -160``.
+wraprange : 2-tuple of float, optional
+    Range outside of which tick values are wrapped. For example,
+    ``(-180, 180)`` will format a value of ``200`` as ``-160``.
 prefix, suffix : str, optional
-    Prefix and suffix for all tick strings.
+    Prefix and suffix for all tick strings. The suffix is added before
+    the optional `negpos` suffix.
 negpos : str, optional
     Length-2 string indicating the suffix for "negative" and "positive"
     numbers, meant to replace the minus sign.
 """
-
-docstring.snippets['formatter.call'] = """
+_formatter_call = """
 Convert number to a string.
 
 Parameters
@@ -60,12 +78,24 @@ x : float
 pos : float, optional
     The position.
 """
+docstring._snippet_manager['ticker.precision'] = _precision_docstring
+docstring._snippet_manager['ticker.zerotrim'] = _zerotrim_docstring
+docstring._snippet_manager['ticker.auto'] = _auto_docstring
+docstring._snippet_manager['ticker.call'] = _formatter_call
+
+_dms_docstring = """
+Parameters
+----------
+dms : bool, optional
+    Locate the ticks on clean degree-minute-second intervals and format the
+    ticks with minutes and seconds instead of decimals. Default is ``False``.
+"""
+docstring._snippet_manager['ticker.dms'] = _dms_docstring
 
 
-class _DegreeLocator(mticker.MaxNLocator):
+class DegreeLocator(mticker.MaxNLocator):
     """
-    A locator for determining longitude and latitude gridlines.
-    Adapted from cartopy.
+    A locator for longitude and latitude gridlines. Adapted from cartopy.
     """
     # NOTE: Locator implementation is weird AF. __init__ just calls set_params with all
     # keyword args and fills in missing params with default_params class attribute.
@@ -73,6 +103,13 @@ class _DegreeLocator(mticker.MaxNLocator):
     default_params = mticker.MaxNLocator.default_params.copy()
     default_params.update(nbins=8, dms=False)
 
+    @docstring._snippet_manager
+    def __init__(self, *args, **kwargs):
+        """
+        %(ticker.dms)s
+        """
+        super().__init__(*args, **kwargs)
+
     def set_params(self, **kwargs):
         if 'dms' in kwargs:
             self._dms = kwargs.pop('dms')
@@ -98,16 +135,14 @@ class _DegreeLocator(mticker.MaxNLocator):
         return self._raw_ticks(vmin, vmax)  # may call Latitude/LongitudeLocator copies
 
 
-class LongitudeLocator(_DegreeLocator):
+class LongitudeLocator(DegreeLocator):
     """
-    A locator for determining longitude gridlines. Adapted from cartopy.
+    A locator for longitude gridlines. Adapted from cartopy.
     """
+    @docstring._snippet_manager
     def __init__(self, *args, **kwargs):
         """
-        Parameters
-        ----------
-        dms : bool, optional
-            Allow the locator to stop on minutes and seconds. Default is ``False``.
+        %(ticker.dms)s
         """
         super().__init__(*args, **kwargs)
 
@@ -129,16 +164,14 @@ class LongitudeLocator(_DegreeLocator):
         return ticks
 
 
-class LatitudeLocator(_DegreeLocator):
+class LatitudeLocator(DegreeLocator):
     """
-    A locator for determining latitude gridlines. Adapted from cartopy.
+    A locator for latitude gridlines. Adapted from cartopy.
     """
+    @docstring._snippet_manager
     def __init__(self, *args, **kwargs):
         """
-        Parameters
-        ----------
-        dms : bool, optional
-            Allow the locator to stop on minutes and seconds. Default is ``False``.
+        %(ticker.dms)s
         """
         super().__init__(*args, **kwargs)
 
@@ -170,33 +203,50 @@ class _CartopyFormatter(object):
         super().__init__(*args, **kwargs)
 
     def __call__(self, value, pos=None):
+        ctx = context._empty_context()
         if self.axis is not None:
-            context = _state_context(self.axis.axes, projection=ccrs.PlateCarree())
-        else:
-            context = _dummy_context()
-        with context:
+            ctx = context._state_context(self.axis.axes, projection=ccrs.PlateCarree())
+        with ctx:
             return super().__call__(value, pos)
 
 
-class _LongitudeFormatter(_CartopyFormatter, LongitudeFormatter):
+class LongitudeFormatter(_CartopyFormatter, LongitudeFormatter):
     """
-    Mix longitude formatter with custom formatter.
+    A formatter for longitude gridlines.
+    Adapted from `cartopy.mpl.ticker.LongitudeFormatter`.
     """
-    pass
+    @docstring._snippet_manager
+    def __init__(self, *args, **kwargs):
+        """
+        %(ticker.dms)s
+        """
+        super().__init__(*args, **kwargs)
 
 
-class _LatitudeFormatter(_CartopyFormatter, LatitudeFormatter):
+class LatitudeFormatter(_CartopyFormatter, LatitudeFormatter):
     """
-    Mix latitude formatter with custom formatter.
+    A formatter for latitude gridlines.
+    Adapted from `cartopy.mpl.ticker.LatitudeFormatter`.
     """
-    pass
+    @docstring._snippet_manager
+    def __init__(self, *args, **kwargs):
+        """
+        %(ticker.dms)s
+        """
+        super().__init__(*args, **kwargs)
 
 
-class _DegreeFormatter(_CartopyFormatter, _PlateCarreeFormatter):
+class DegreeFormatter(_CartopyFormatter, _PlateCarreeFormatter):
     """
-    Mix Plate Carrée formatter with custom formatter and add base methods
-    that permit using this as degree-minute-second formatter anywhere.
+    A formatter for longitude and latitude gridlines. Adapted from cartopy.
     """
+    @docstring._snippet_manager
+    def __init__(self, *args, **kwargs):
+        """
+        %(ticker.dms)s
+        """
+        super().__init__(*args, **kwargs)
+
     def _apply_transform(self, value, *args, **kwargs):  # noqa: U100
         return value
 
@@ -204,17 +254,39 @@ class _DegreeFormatter(_CartopyFormatter, _PlateCarreeFormatter):
         return ''
 
 
+class IndexFormatter(mticker.Formatter):
+    """
+    A duplicate of `~matplotlib.ticker.IndexFormatter`.
+    """
+    # NOTE: This was deprecated in matplotlib 3.3. For details check out
+    # https://github.com/matplotlib/matplotlib/issues/16631 and bring some popcorn.
+    def __init__(self, labels):
+        self.labels = labels
+        self.n = len(labels)
+
+    def __call__(self, x, pos=None):  # noqa: U100
+        i = int(round(x))
+        if i < 0 or i >= self.n:
+            return ''
+        else:
+            return self.labels[i]
+
+
+def _default_precision_zerotrim(precision=None, zerotrim=None):
+    """
+    Return the default zerotrim and precision. Shared by several formatters.
+    """
+    zerotrim = _not_none(zerotrim, rc['formatter.zerotrim'])
+    if precision is None:
+        precision = 6 if zerotrim else 2
+    return precision, zerotrim
+
+
 class AutoFormatter(mticker.ScalarFormatter):
     """
-    The new default formatter. Differs from `~matplotlib.ticker.ScalarFormatter`
-    in the following ways:
-
-    1. Trims trailing decimal zeros by default.
-    2. Permits specifying *range* within which major tick marks are labeled.
-    3. Permits adding arbitrary prefix or suffix to every tick label string.
-    4. Permits adding "negative" and "positive" indicator.
+    The new default tick label formatter.
     """
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __init__(
         self,
         zerotrim=None, tickrange=None, wraprange=None,
@@ -224,24 +296,25 @@ class AutoFormatter(mticker.ScalarFormatter):
         """
         Parameters
         ----------
-        %(formatter.params)s
+        %(ticker.zerotrim)s
+        %(ticker.auto)s
 
         Other parameters
         ----------------
         **kwargs
-            Passed to `~matplotlib.ticker.ScalarFormatter`.
+            Passed to `matplotlib.ticker.ScalarFormatter`.
 
-        Warning
-        -------
-        The matplotlib `~matplotlib.ticker.ScalarFormatter` determines the
-        number of significant digits based on the axis limits, and therefore
-        may *truncate* digits while formatting ticks on highly non-linear
-        axis scales like `~proplot.scale.LogScale`. We try to correct
-        this behavior with a patch.
+        Note
+        ----
+        `matplotlib.ticker.ScalarFormatter` determines the number of
+        significant digits based on the axis limits, and therefore may
+        truncate digits while formatting ticks on highly non-linear axis
+        scales like `~proplot.scale.LogScale`. `AutoFormatter` corrects
+        this behavior, making it suitable for arbitrary axis scales. We
+        therefore use `AutoFormatter` with every axis scale by default.
         """
         tickrange = tickrange or (-np.inf, np.inf)
         super().__init__(**kwargs)
-        from .config import rc
         zerotrim = _not_none(zerotrim, rc['formatter.zerotrim'])
         self._zerotrim = zerotrim
         self._tickrange = tickrange
@@ -250,10 +323,10 @@ class AutoFormatter(mticker.ScalarFormatter):
         self._suffix = suffix or ''
         self._negpos = negpos or ''
 
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __call__(self, x, pos=None):
         """
-        %(formatter.call)s
+        %(ticker.call)s
         """
         # Tick range limitation
         x = self._wrap_tick_range(x, self._wraprange)
@@ -283,7 +356,7 @@ class AutoFormatter(mticker.ScalarFormatter):
         """
         Get the offset but *always* use math text.
         """
-        with _state_context(self, _useMathText=True):
+        with context._state_context(self, _useMathText=True):
             return super().get_offset()
 
     @staticmethod
@@ -308,7 +381,7 @@ class AutoFormatter(mticker.ScalarFormatter):
         # only meant to be used for linear scales and cannot handle the wide
         # range of magnitudes in e.g. log scales. To correct this, we only
         # truncate if value is within `offset` order of magnitude of the float
-        # precision. Common issue is e.g. levels=plot.arange(-1, 1, 0.1).
+        # precision. Common issue is e.g. levels=pplt.arange(-1, 1, 0.1).
         # This choice satisfies even 1000 additions of 0.1 to -100.
         match = REGEX_ZERO.match(string)
         decimal_point = self._get_decimal_point()
@@ -341,18 +414,14 @@ class AutoFormatter(mticker.ScalarFormatter):
         """
         Get decimal point symbol for current locale (e.g. in Europe will be comma).
         """
-        from .config import rc
-        use_locale = _not_none(
-            use_locale, self.get_useLocale(), rc['formatter.use_locale']
-        )
-        return locale.localeconv()['decimal_point'] if use_locale else '.'
+        use_locale = _not_none(use_locale, self.get_useLocale())
+        return self._get_default_decimal_point(use_locale)
 
     @staticmethod
     def _get_default_decimal_point(use_locale=None):
         """
         Get decimal point symbol for current locale. Called externally.
         """
-        from .config import rc
         use_locale = _not_none(use_locale, rc['formatter.use_locale'])
         return locale.localeconv()['decimal_point'] if use_locale else '.'
 
@@ -361,7 +430,6 @@ class AutoFormatter(mticker.ScalarFormatter):
         """
         Format the minus sign and avoid "negative zero," e.g. ``-0.000``.
         """
-        from .config import rc
         if rc['axes.unicode_minus'] and not rc['text.usetex']:
             string = string.replace('-', '\N{MINUS SIGN}')
         if REGEX_MINUS_ZERO.match(string):
@@ -424,27 +492,22 @@ class SciFormatter(mticker.Formatter):
     """
     Format numbers with scientific notation.
     """
+    @docstring._snippet_manager
     def __init__(self, precision=None, zerotrim=None):
         """
         Parameters
         ----------
-        precision : int, optional
-            The maximum number of digits after the decimal point. Default is ``6``
-            when `zerotrim` is ``True`` and ``2`` otherwise.
-        zerotrim : bool, optional
-            Whether to trim trailing zeros. Default is
+        %(ticker.precision)s
+        %(ticker.zerotrim)s
         """
-        from .config import rc
-        zerotrim = _not_none(zerotrim, rc['formatter.zerotrim'])
-        if precision is None:
-            precision = 6 if zerotrim else 2
+        precision, zerotrim = _default_precision_zerotrim(precision, zerotrim)
         self._precision = precision
         self._zerotrim = zerotrim
 
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __call__(self, x, pos=None):  # noqa: U100
         """
-        %(formatter.call)s
+        %(ticker.call)s
         """
         # Get string
         decimal_point = AutoFormatter._get_default_decimal_point()
@@ -475,25 +538,24 @@ class SciFormatter(mticker.Formatter):
 
 class SigFigFormatter(mticker.Formatter):
     """
-    Rounds numbers to the specified number of *significant digits*.
+    Format numbers by retaining the specified number of significant digits.
     """
+    @docstring._snippet_manager
     def __init__(self, sigfig=3, zerotrim=None):
         """
         Parameters
         ----------
         sigfig : float, optional
             The number of significant digits.
-        zerotrim : bool, optional
-            Whether to trim trailing zeros.
+        %(ticker.zerotrim)s
         """
-        from .config import rc
         self._sigfig = sigfig
         self._zerotrim = _not_none(zerotrim, rc['formatter.zerotrim'])
 
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __call__(self, x, pos=None):  # noqa: U100
         """
-        %(formatter.call)s
+        %(ticker.call)s
         """
         # Limit digits to significant figures
         if x == 0:
@@ -515,11 +577,11 @@ class SigFigFormatter(mticker.Formatter):
 
 class SimpleFormatter(mticker.Formatter):
     """
-    Replicate various features from `AutoFormatter`. This is more suitable for
-    arbitrary number formatting not necessarily associated with any
-    `~matplotlib.axis.Axis` instance, e.g. labeling contours.
+    A general purpose number formatter. This is similar to `AutoFormatter`
+    but suitable for arbitrary formatting not necessarily associated with
+    an `~matplotlib.axis.Axis` instance.
     """
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __init__(
         self, precision=None, zerotrim=None,
         tickrange=None, wraprange=None,
@@ -528,15 +590,11 @@ class SimpleFormatter(mticker.Formatter):
         """
         Parameters
         ----------
-        precision : int, optional
-            The maximum number of digits after the decimal point. Default is ``6``
-            when `zerotrim` is ``True`` and ``2`` otherwise.
-        %(formatter.params)s
+        %(ticker.precision)s
+        %(ticker.zerotrim)s
+        %(ticker.auto)s
         """
-        from .config import rc
-        zerotrim = _not_none(zerotrim, rc['formatter.zerotrim'])
-        if precision is None:
-            precision = 6 if zerotrim else 2
+        precision, zerotrim = _default_precision_zerotrim(precision, zerotrim)
         self._precision = precision
         self._prefix = prefix or ''
         self._suffix = suffix or ''
@@ -545,10 +603,10 @@ class SimpleFormatter(mticker.Formatter):
         self._wraprange = wraprange
         self._zerotrim = zerotrim
 
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __call__(self, x, pos=None):  # noqa: U100
         """
-        %(formatter.call)s
+        %(ticker.call)s
         """
         # Tick range limitation
         x = AutoFormatter._wrap_tick_range(x, self._wraprange)
@@ -578,7 +636,7 @@ class SimpleFormatter(mticker.Formatter):
 
 class FracFormatter(mticker.Formatter):
     r"""
-    Format numbers as fractions or multiples of some arbitrary value.
+    Format numbers as fractions or multiples of some value.
     This is powered by the builtin `~fractions.Fraction` class
     and the `~fractions.Fraction.limit_denominator` method.
     """
@@ -595,10 +653,10 @@ class FracFormatter(mticker.Formatter):
         self._number = number
         super().__init__()
 
-    @docstring.add_snippets
+    @docstring._snippet_manager
     def __call__(self, x, pos=None):  # noqa: U100
         """
-        %(formatter.call)s
+        %(ticker.call)s
         """
         frac = Fraction(x / self._number).limit_denominator()
         symbol = self._symbol
